# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['mlbv', 'mlbv.mlbam', 'mlbv.mlbam.common', 'mlbv.test']

package_data = \
{'': ['*']}

install_requires = \
['lxml>=4.6.3,<5.0.0',
 'python-dateutil>=2.8.1,<3.0.0',
 'requests>=2.25.1,<3.0.0',
 'streamlink>=2.1.1,<3.0.0']

entry_points = \
{'console_scripts': ['mlbv = mlbv.mlbam.mlbv:main']}

setup_kwargs = {
    'name': 'mlbv',
    'version': '0.0.18',
    'description': 'Command-line interface to MLB game information, game schedule and scores',
    'long_description': "mlbv - MLB stream viewer\n========================\n\n`mlbv` is a command-line interface to the MLB.tv service. It's primary purpose is to allow you to view game\nstreams on linux, including live streams, with a valid MLB tv subscription.  It also allows you to view game\nstatus, results and schedules, stream highlights (recap and condensed games), and filter results based on\nfavourite teams.\n\nFeatures:\n\n* stream or record live or archived MLB games (requires MLB.tv subscription)\n* show completed game highlights (condensed or recap) (no subscription required)\n* display game schedules for given day or number of days\n    - option to show or hide scores\n* filter display based on favourite teams\n* show standings\n\n\nThis project is inspired from the [streamglob](https://github.com/tonycpsu/streamglob) project, although it\ndiffers in that it does not provide an interactive interface. It strictly command-line based, although it does\noffer quite a few options to view game-related data.  This project allows you to quickly find the game,\nstatus, or highlights of your favourite team.\n\nNote: if you have [fzf](https://github.com/junegunn/fzf) installed, try using the included wrapper script **`mlbv-fzf`** \nwhich provides a more interactive interface for game selection.\n\nThis package requires a valid MLB.tv subscription in order to view live or archived games. It is also subject\nto local blackout restrictions. However, if you don't have a subscription you can still view game recaps or\ncondensed games.\n\n\nSample console output (default, no linescore):\n\n````\n       2018-04-10 Tue                            Series  │ Score │   State   │ Feeds\n─────────────────────────────────────────────────────────┼───────┼───────────┼────────────────\n14:10: Tampa Bay (TB) at Chi White Sox (CWS)       2/3   │  6-5  │ Final     │ a,h cnd,rcp\n14:20: Pittsburgh (PIT) at Chi Cubs (CHC)          1/3   │  8-5  │ Final     │ a,h,ima cnd,rcp\n18:10: Detroit (DET) at Cleveland (CLE)            2/4   │  1-2  │ Final     │ a,h cnd,rcp\n19:05: Atlanta (ATL) at Washington (WSH)           2/3   │  1-4  │ Final     │ a,h cnd,rcp\n19:05: Cincinnati (CIN) at Philadelphia (PHI)      2/3   │  1-6  │ Final     │ a,h cnd,rcp\n19:05: Toronto (TOR) at Baltimore (BAL)            2/3   │  2-1  │ Final     │ a,h cnd,rcp\n19:10: NY Mets (NYM) at Miami (MIA)                2/3   │  8-6  │ Final     │ a,h cnd,rcp\n19:10: NY Yankees (NYY) at Boston (BOS)            1/3   │ 1-14  │ Final     │ a,h cnd,rcp\n20:05: LA Angels (LAA) at Texas (TEX)              2/3   │ 11-1  │ Final     │ a,h cnd,rcp\n20:10: Houston (HOU) at Minnesota (MIN)            2/3   │  1-4  │ Final     │ a,h,ima cnd,rcp\n20:15: Milwaukee (MIL) at St. Louis (STL)          2/3   │  3-5  │ Final(11) │ a,h cnd,rcp\n20:15: Seattle (SEA) at Kansas City (KC)           2/3   │  8-3  │ Final     │ a,h,ima cnd,rcp\n20:40: San Diego (SD) at Colorado (COL)            2/3   │  5-2  │ Final     │ a,h,imh cnd,rcp\n22:10: Oakland (OAK) at LA Dodgers (LAD)           1/2   │  0-4  │ Final     │ a,h cnd,rcp\n22:15: Arizona (ARI) at San Francisco (SF)         2/3   │  4-5  │ Final     │ a,h cnd,rcp\n````\n\nLinescore output:\n\n````\n       2018-04-10 Tue\n───────────────────────────────────────────────────────────────────────────────────────────\n19:05: Toronto (TOR) at Baltimore (BAL)                  1  2  3  4  5  6  7  8  9  R  H  E\n2/3    Final: 2-1                                  TOR   0  0  0  0  0  0  0  1  1  2  7  0\n       Feeds: a,h cnd,rcp                          BAL   0  0  0  0  0  0  0  1  0  1  3  2\n───────────────────────────────────────────────────────────────────────────────────────────\n````\n\nStandings output:\n\n````\n   ═════════ Division ═════════   W   L PCT   GB   WGB  Streak\n   ─── American League West ────────────────────────────────\n1  Los Angeles Angels            12   3 .800  -    -    [W6]\n2  Houston Astros                10   4 .714  1.5  +1.0 [W1]\n3  Seattle Mariners               7   4 .636  3.0  0.5  [W3]\n4  Oakland Athletics              5   9 .357  6.5  4.0  [L1]\n5  Texas Rangers                  4  11 .267  8.0  5.5  [L5]\n   ─── American League East ────────────────────────────────\n1  Boston Red Sox                11   2 .846  -    -    [W2]\n2  Toronto Blue Jays              9   5 .643  2.5  -    [W1]\n3  New York Yankees               7   7 .500  4.5  2.0  [W1]\n4  Baltimore Orioles              5   9 .357  6.5  4.0  [L1]\n5  Tampa Bay Rays                 3  10 .231  8.0  5.5  [L2]\n   ─── American League Central ─────────────────────────────\n1  Minnesota Twins                7   4 .636  -    -    [W3]\n2  Cleveland Indians              8   6 .571  0.5  1.0  [L1]\n3  Chicago White Sox              4   8 .333  3.5  4.0  [L1]\n4  Detroit Tigers                 4   9 .308  4.0  4.5  [L5]\n5  Kansas City Royals             3   9 .250  4.5  5.0  [L4]\n   ─── National League Central ─────────────────────────────\n1  Pittsburgh Pirates             9   4 .692  -    -    [L1]\n2  Milwaukee Brewers              7   7 .500  2.5  1.0  [L1]\n3  St. Louis Cardinals            7   7 .500  2.5  1.0  [W2]\n4  Chicago Cubs                   6   7 .462  3.0  1.5  [L2]\n5  Cincinnati Reds                2  11 .154  7.0  5.5  [L6]\n   ─── National League West ────────────────────────────────\n1  Arizona Diamondbacks          10   3 .769  -    -    [W2]\n2  Colorado Rockies               8   7 .533  3.0  0.5  [W3]\n3  San Francisco Giants           6   7 .462  4.0  1.5  [L1]\n4  Los Angeles Dodgers            4   8 .333  5.5  3.0  [L2]\n5  San Diego Padres               5  10 .333  6.0  3.5  [W1]\n   ─── National League East ────────────────────────────────\n1  New York Mets                 11   1 .917  -    -    [W9]\n2  Atlanta Braves                 8   5 .615  3.5  +0.5 [W2]\n3  Philadelphia Phillies          7   5 .583  4.0  -    [W4]\n4  Washington Nationals           6   8 .429  6.0  2.0  [L3]\n5  Miami Marlins                  4   9 .308  7.5  3.5  [W1]\n````\n\nThis project incorporates some code modified from the following projects: \n\n* [mlbstreamer](https://github.com/tonycpsu/mlbstreamer): a similar project. \n    - Session authentication code is taken shamelessly from this project.\n* [Kodi plugin.video.mlbtv](https://github.com/eracknaphobia/plugin.video.mlbtv)\n\n\n## Pre-Requisites:\n\n`mlbv` requires the following software to be installed and configured:\n\n* python \n    - python v3 (tested with 3.6) \n* python modules (installed by `pip install`):\n    - [requests](http://python-requests.org/) module \n    - [python-dateutil](https://dateutil.readthedocs.io/en/stable/) module\n    - [python-lxml](http://lxml.de/) module\n* [streamlink](https://streamlink.github.io/)\n* a video player. Either `vlc` or `mpv` is recommended.\n    - Note: player can be specified via config file. If player is not on the system path you may need to\n      setup the full path in the config file.\n\nThis software is tested under linux. It should work under Windows or Mac with the pre-requisites installed,\nbut may require minor tweaks (bug reports are welcome).\n\n\n## 1. Installation\n\n### Via pip\n\nThis project is on the Python Package Index (Pypi) at [mlbv](https://pypi.org/project/mlbv), and can be\ninstalled using `pip`.\n\n1. Run `pip install mlbv`\n2. Run `mlbv --init` to create a configuration directory and populate the `config` file\n   with defaults and the required MLB.tv username and password. See the next section for more details.\n\n### Archlinux\n\nInstall `mlbv` via the AUR.\n\n\n## 2. Configuration\n\nAfter installing, run:\n\n    mlbv --init\n\nThis will create the initial config file/directory and populate it with the prompted MLB.tv username and password.\nThe `config` file will be located at `$HOME/.config/mlbv/config`. Directories are created if necessary.\n\nOther properties in the config file are documented in the file itself. If you want to stream live or archived\ngames then you must provide valid login credentials (if you don't have MLB.tv you can still see scores and\nwatch highlights).\n\nSome properties you may want to set in the `config` file:\n\n* `username`: MLB.tv account username\n* `password`: MLB.tv account password\n* `favs`: a comma-separated list of team codes which:\n    - 1) are highlighted in the game data, and \n    - 2) are used for the default filter in the `-o/--filter` option (to show only the favourite team(s))\n* `scores`: a boolean specifying whether or not you want to see scores in the game information. Warning: spoilers!\n* `resolution`: the stream quality (passed in to streamlink). Use '720p_alt' for full HD at 60 frames/sec.\n    - options are: 'worst', '224p', '288p', '360p', '504p', '540p', '720p', '720p_alt', 'best'\n* `linescore`: to enable linescores by default (if scores are enabled)\n\n\n## 3. QUICKSTART\n\nHere's a quick overview of the most common usage options:\n\n    mlbv               # show today's schedule/scores\n    mlbv -l            # show today's linescores\n    mlbv -t tor        # play today's Jays game, either live (if in-progress), or from the start (if archived)\n    mlbv --recaps      # play all of today's recaps\n    mlbv --standings   # show current standings\n\n\nHelp is available by running:\n\n    mlbv --help   # short help\n    mlbv --usage  # view full documenation\n \n\n## 4. Default Behaviour: Show Schedule/Scores\n\nRunning `mlbv` by itself shows you the status of today's games, including scores (unless you've configured to hide scores by default).\n\n### Scores/No-Scores\n\nThe `scores` option in the config file controls whether or not scores are shown. If false then no scores are\nshown. Scores are also not shown before a feed is launched.\n\nYou can temporarily override the config file using either `-s/--scores` or `-n/--no-scores` options.\n\n\n### Linescores\n\nLinescores are displayed using the `-l/--linescore` option. You can also make linescores the default in the config file.\n\nSince linescores take up more screen real estate it can be useful to combine them with a filter to limit the number of games shown. \n\n\n### Dates and Filters\n\nSee the sections below on Dates and Filters for more information on specifying dates and filtering output based on\nleague, division, favourites, or arbitrary teams.\n\n\n> Note on Arguments\n> \n> Frequently used arguments have both a long form with double-dash `--` argument and a short form which uses a single dash `-`. \n> \n> For the long form arguments, you can shorten any option name down to the shortest unique value.  For example,\n> rather than having to type `--yesterday` you can shorten it right down to `--y`.  However, you can only\n> shorten `--tomorrow` down to `--to` since there is also the `--team` option (which makes `--t` non-unique).\n\n\n### Show Extra Information (--info)\n\nThe --info option will show extra textual information for either the game preview or the game summary (depending on which is available).\nThe extra information is displayed inline, within the game info.\n\n- Pregame: shows probable starting pitchers (when available).\n- Postgame (when available): shows game summary, and full game recap article.\n\nThe default for `--info` is actually equivalent to `--info=full`. \nIf you want to have a more brief set of extra information, use `--info=short` or just `--info short`.\nYou can also permanently set the `full/short` default for this setting via the `config` file setting:\n`info_display_articles=true|false` (i.e. setting info_display_articles=false will cause `--info` to \nbehave like `--info=short`).\n\nNOTE: Since there may be a lot of text to present, this option tends to work best with the `-o/--filter` option,\nwhich filters the display out by a team or set of teams. See the 'Filters' section for more information'\n\n\nExamples:\n\n    mlbv --info --yes     # show yesterday's games with full article info\n    mlbv --info -o --yes  # show yesterday's games with full article info, filtered by favs\n    mlbv --info -o tor,bos --yes  # show yesterday's games with full article info, filtered for only tor,bos\n\n    mlbv --info=short --yes  # show yesterday's games with only summary info\n\n    mlbv --info        # show today's games with full info (probable pitchers, with details)\n    mlbv --info -o     # show today's games with full info (probable pitchers only), filtered by favs\n    mlbv --info short  # show today's games with summary info (probable pitchers only)\n\n\n## 5. Watching a Live or Archived Game\n\nWatching a game is triggered by the `-t/--team TEAM` option. With this option the game stream (live or\narchived) is launched for the given team. \n\nWhen passing `-t/--team TEAM` option, the stream is launched for the given team. By default the local feed\nfor the given team is chosen - i.e., it will follow the home/away feed appropriate for the team so that you\nget the local team feed.  You can override the feed using the `-f/--feed` option. This works for either live\ngames or for archived games (e.g. if you use the `--date` option to select an earlier date).\n\nExample:\n\n    mlbv --team tor          # play the live Blue Jays game\n    mlbv --yesterday -t tor  # play yesterday's Blue Jays game (see below for options on specifying dates)\n\n\n### Feed Selection\n\nBy default the local feed for the given team is chosen - i.e., it will follow the home/away feed appropriate\nfor the given team so that you get the team's local feed if available.  You can override the feed using the\n`-f/--feed` option. This works for either live games or for archived games (e.g. if you use the `--date`\noption to select an earlier date).\n\n    mlbv --team tor --feed away  # choose the away feed (assuming Toronto is the home team, you will get the\n                                 # opposing team's feed)\n\n\n### Specifying Stream Start Location\n\nFor an in-progress game, the stream will join the live game at the current time. Use either  `--from-start` or\nthe `--inning/-i` option to override this behaviour.\n\nFor an archived game, the stream will start from the beginning.\n\n\n#### Start from Inning\n\nFor both live and archived games you can start from the top or bottom of an inning:\n\n    mlbv --team tor --inning t5  # start from top of 5th\n    mlbv -t tor -i t5            # same thing but with short switches\n    mlbv --team tor --inning b5  # start from bottom of 5th\n\n\n#### Start from Beginning (Live Game)\n\nFor a live game, you can start from the beginning with:\n\n    mlbv --team tor --from-start  # start stream at beginning, live games only\n\n\n### Doubleheaders\n\nIf a game is a doubleheader then you can select the second game using the `-g/--game` argument. \nBy default it will select the first game.\n\n\n## 6. Record/Fetch\n\nIf you pass the `-f/--fetch` option, instead of launching the video player, the selected stream is saved to\ndisk. The stream is named to convention: `<date>-<away_team>-<home_team>-<feed>.ts`.\n\n- Live games have extension `.ts`, highlight games are `.mp4`\n\n\nExample: `2018-03-31-nyy-tor-home.ts`.\n\nIf your player supports it, you can select the stream to fetch, then manually launch your video player at a\nlater time while the stream is being saved to file. \n\nExample:\n\n    mlbv --team tor --fetch  # Fetch the live jays game to disk. \n                             # Most video players allow you to view while downloading\n\n\n## 7. Highlights: Recap or Condensed Games\n\nPlaying the game highlight is triggered by using the `-f/--feed` option. The `recap` or `condensed` feeds show\nup after a game has ended. To watch the highlight, specify one of those feeds along with the team name in the\n`-t/--team` option.\n\nExample:\n\n    mlbv --team tor -f condensed\n    mlbv --team tor -f recap\n\nNOTE: You don't need login credentials to play highlights.\n\n\n### Playing Multiple Game Recaps (for a given day)\n\nThe `--recaps` option lets you select a batch of game recaps to watch for a given day.\nThis option shows game recaps either for all games or for a selected set of teams (using a filter).\nIf no argument is given to `recaps` then no filter is applied.\n\nUsage:\n\n    --recaps ?filter?  : filter is optional, if not supplied then all games are selected\n\nExamples:\n\n    mlbv --recaps                       # show all available game recaps for today's games\n    mlbv --yesterday --recaps           # show all available game recaps for yesterday's games\n    mlbv --yesterday --recaps ale       # show available game recaps for yesterday's games\n                                        # in the American League East\n    mlbv --yesterday --recaps tor,wsh   # show game recaps for yesterday's Toronto, Boston games\n    mlbv --yesterday --recaps tor,wsh --fetch   # same as above but save to disk instead of view\n\n\n## 8. Specifying Dates\n\nYou can specify the date to view using one of the following:\n\n    -d|--date yyyy-mm-dd    # specific date\n    --yesterday (or --yes)  # shortcut to yesterday\n    --tomorrow  (or --tom)  # shortcut to tomorrow\n\nFor listing game data only (doesn't make sense for viewing), you can specify a number of days using the\n`--days DAYS` option. Use this to show a schedule. It's useful with the `--filter` option to filter based on\nfavourite team(s).\n\n\n## 9. Filters\n\nYou can filter the schedule/scores displays using the `-o/--filter` argument. \nThe filter argument allows you to provide either a built-in filter name or a comma-separated list of team codes.\n\nThe filter option has the form:\n\n    -o/--filter ?filter?  : where ?filter? is optional, and is either \n                            a 'filter name' or a comma-separated list of teams\n\n> Note: -o is used as the short form because -f is taken. mnemonic: -o -> 'only'\n\n> Note: Aside from the `--filter` command, other command arguments accept the same 'filter' string.\n>       For example `--linescore ?filter?` and `--recaps ?filter?`\n\n\n### Built-in Filters\n\nIf `?filter?` is not given then the built-in filter `favs` is used. `favs` is a filter which you can define \nin the config file to list your favourite team(s).\n\nOther built-in filters are available which group teams by league and division. The filter names are:\n\n* `al`, `ale`, `alc`, `alw` (American League, AL East, AL Central, AL West)\n* `nl`, `nle`, `nlc`, `nlw` (National League, NL East, NL Central, NL West)\n\nUsing one of the above filter names will include those selected teams in the output.\n\n\n### Ad-hoc Filters\n\nYou can also use any comma-separated list of team codes for a filter.\n\nExamples:\n\n    --filter tor            # single team filter\n    --filter tor,bos,wsh    # multiple team filter\n    -o tor,bos,wsh          # same as above using shorter `-o` form\n\nNote: Do not use spaces between commas unless you encapsulate the list in quotes.\n\n\n## 10. Standings\n\nYou can display standings via the `--standings [category]` option. This option displays the given standings category then exits.\n\nYou can also specify a league or division filter via `-o/--filter`.\n\nStandings categories:\n\n* all\n* division [default]\n* conference\n* wildcard\n* league\n* postseason\n* preseason\n\nBy default, the division standings are displayed for today's date. \nYou can add the `-d/--date yyyy-mm-dd` option to show standings for any given date.\n\nYou don't have to specify the full standings category, it will match any substring given. e.g. `--standings d`\nwill match division or `--standings wild` will match wildcard.\n\nYou can also use the `-o/--filter` option to narrow down what is displayed. e.g. `--standings division --filter ale`\n\n\n## 10. Statistics\n\nYou can display statistics via the `--stats` option. This option displays the given statistics category then exits.\n\nThere are two main stats categories:\n- league\n- team\n\nThe stats category and further options are selected via arguments to `--stats`:\n\n    league|<team>[:category][:qualifier]\n\nWhere the category and qualifier are used to narrow down the statistics returned.  The category is one of 'hitting', 'fielding', or\n'pitching', while the qualifier differs for league and team stats. These are outlined further in their respective sections below.\n\nBy default, the league standings are displayed for today's date. \nYou can also add the `-d/--date yyyy-mm-dd` option to show standings for any given date.\n\n\n### Categories\n\nStatistics are broken out into three main categories:\n\n- hitting\n- fielding\n- pitching\n\nBy default, all three categories are shown. You can specify any of the above to limit the output to one of the main categories.\n\n> You don't have to specify the full statistics category, it will match any substring given. e.g. `--stats league:h`\n> is the same as `league:hitting`.\n\n\n### League Statistics\n\nThe league stats show the leaders over the three main categories, for various statistic measurements.\n\nThe league `--stats` format is:\n\n    league:[category]:[qualifier]\n        [category]: one of: hitting, fielding, pitching, all [default: all]\n        [qualifier]: all, qualified, rookies [default: qualified]\n\nFilters:\n\nLeague stats can be filtered by league. Valid filters are `al`, `american`, or `nl`, `national`. These are specified via the standard `-o/--filter` option.\n\nExamples:\n\n    mlbv --stats league                    # league stats for all categories, qualified players\n    mlbv --stats league:hitting:qualified  # hitting stats, include qualified players (default)\n    mlbv --stats league:hitting:rookies    # hitting stats, only rookies\n    mlbv --stats league::rookies           # rookie leaders, all categories\n    mlbv --stats league:hitting:all        # hitting stats, all players\n    mlbv --stats league:fielding\n    mlbv --stats league:pitching\n    mlbv --stats league:pitching -o al     # filter by american league\n    mlbv --stats league -o nl              # filter by american league\n\n\nYou can also include --date, to specify the season (league stats are per-season):\n\n    mlbv --stats league --date 2010  # league stats for 2010\n\nBy default, 10 entries are given for each individual displayed statistic. You can override this via a config setting: `stats_limit`. For\nexample, you could add this to your config file to only show 5 entries per individual statistic:\n\n    stats_limit=5\n\n\n### Team Statistics\n\nThe second form of statistics are for a given team. Here you use the team abbreviation plus the optional category:qualifier.\nThe team form is\n\n    <team>:[category]:[qualifier]\n        <team>: the team abbreviation\n        [category]: one of: hitting, fielding, pitching, all [default: all]\n        [qualifier]: the roster type: active, full, 40man\n\n    Examples: tor:hitting:active  # active roster only (default)\n              tor:hitting:full    # full season roster\n              tor:hitting:40man   # 40-man roster\n              nyy:pitching        # Yankees pitching\n              bos:fielding        # Red Sox fielding\n\n\n> You don't have to specify the full statistics category, it will match any substring given. e.g. `--stats <team>:h`\n> is the same as `<team>:hitting`.\n\nExamples:\n\n    mlbv --stats tor                       # Blue Jays stats for all categories, qualified players\n    mlbv --stats tor:pitching              # Blue Jays pitching stats\n    mlbv --stats tor::full                 # Blue Jays stats, all categories, full season roster\n\nYou can also include --date, narrowed down to a particular day (unlike league stats which are only specified for an entire season):\n\n    mlbv --stats tor --date 2010-08-01  # Blue Jays team stats on 2010-08-01\n\n\n## 11. Examples\n\nNote: the common options have both short and long options. Both are shown in these examples.\n\n\n### Live Games\n\n    mlbv --team tor               # play the live Jays game. The feed is chosen based on Jays being home vs. away\n    mlbv -t tor --feed national   # play live game, choose the national feed\n    mlbv -t tor --feed away       # play live game, choose the away feed. If the Jays are the home team this would choose\n                                  # the opponent's feed\n\n### Archived Games\n\n    mlbv --yesterday -t tor        # play yesterday's Jays game\n    mlbv --date 2018-03-31 -t tor  # watch the Jays beat the Yankees #spoiler\n\n\n### Highlights\n\nUse the `--feed` option to select the highlight feed (`recap` or `condensed`):\n\n    mlbv --yesterday -t tor --feed condensed  # condensed feed\n    mlbv --yesterday -t tor -f recap          # recap feed\n\nYou can also use the `--recaps` option to show highlights for games on given day.\nThis will show all chosen recaps, one-by-one until finished. A highlight reel.\n\n    mlbv --yesterday --recaps all         # show all available recaps for yesterday games\n    mlbv --yesterday --recaps --filter    # show recaps for favourites\n    mlbv --yesterday --recaps tor,wsh,bos # show recaps for given set of teams\n    mlbv --yesterday --recaps --fetch     # fetch all recaps\n\n### Fetch\n\nIn these examples the game is saved to a file (.ts or .mp4) in the current directory.\n\n    mlbv --team tor --fetch\n    mlbv --yesterday -t tor -f recap --fetch   # fetch yesterday's recap\n\n### Using `--days` for Schedule View\n\n    mlbv --days 7           # show schedule for upcoming week\n    mlbv --days 7 --filter  # show schedule for upcoming week, filtered on favourite teams (from config file)\n    mlbv --days 7 --filter --favs 'tor,wsh' # show schedule filtered on favourite teams (from option)\n\n### Linescores\n\n    mlbv -l        # show linescores for today\n    mlbv --yes -l  # show linescores for yesterday\n    mlbv --date 2018-03-29 --linescore --days 7 --filter  # show linescores for favs in week 1\n\n### Standings\n\n    mlbv --standings             # display division standings\n    mlbv --standings division    # display division standings\n    mlbv --standings div -o ale  # display AL East division standings\n    mlbv --standings league      # display overall league standings\n    mlbv --standings all         # display all regular season standings categories\n\n    mlbv --standings --date 2015-10-01  # display division standings for Oct 1, 2015\n\n",
    'author': 'kmac',
    'author_email': '135567+kmac@users.noreply.github.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/kmac/mlbv',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
